@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Element/FieldSet.pm
-## Version v0.2.0
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.2.1
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/12/23
-## Modified 2022/09/18
+## Modified 2024/04/30
 ## All rights reserved
 ## 
 ## 
@@ -19,7 +19,7 @@ BEGIN
     use parent qw( HTML::Object::DOM::Element );
     use vars qw( $VERSION );
     use HTML::Object::DOM::Element::Shared qw( :fieldset );
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -49,7 +49,7 @@ sub elements
     my $form_elements = $self->new_array( [qw( button fieldset input object output select textarea )] );
     my $list = $form_elements->as_hash;
     my $results = $children->grep(sub{ exists( $form_elements->{ $_->tag } ) });
-    my $col = $self->new_collection;
+    my $col = $self->new_collection_elements;
     $col->push( $results->list );
     return( $col );
 }
@@ -89,7 +89,7 @@ HTML::Object::DOM::Element::FieldSet - HTML Object DOM Field Set Class
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
